@@ -1,16 +1,12 @@
-# -*- coding: utf-8 -*-
-try:
-    from functools import total_ordering
-except ImportError:
-    # Python 2.6 port
-    from total_ordering import total_ordering
-from sqlalchemy_utils import i18n
-from sqlalchemy_utils.utils import str_coercible
+from functools import total_ordering
+
+from .. import i18n
+from ..utils import str_coercible
 
 
 @str_coercible
 @total_ordering
-class WeekDay(object):
+class WeekDay:
     NUM_WEEK_DAYS = 7
 
     def __init__(self, index):
@@ -33,7 +29,7 @@ class WeekDay(object):
         return self.position < other.position
 
     def __repr__(self):
-        return '%s(%r)' % (self.__class__.__name__, self.index)
+        return f'{self.__class__.__name__}({self.index!r})'
 
     def __unicode__(self):
         return self.name
