@@ -1,4 +1,3 @@
-import six
 from sqlalchemy import types
 
 from ..exceptions import ImproperlyConfigured
@@ -8,7 +7,7 @@ colour = None
 try:
     import colour
     python_colour_type = colour.Color
-except ImportError:
+except (ImportError, AttributeError):
     python_colour_type = None
 
 
@@ -61,12 +60,12 @@ class ColorType(ScalarCoercible, types.TypeDecorator):
                 "'colour' package is required to use 'ColorType'"
             )
 
-        super(ColorType, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.impl = types.Unicode(max_length)
 
     def process_bind_param(self, value, dialect):
         if value and isinstance(value, colour.Color):
-            return six.text_type(getattr(value, self.STORE_FORMAT))
+            return str(getattr(value, self.STORE_FORMAT))
         return value
 
     def process_result_value(self, value, dialect):
