@@ -95,7 +95,7 @@ def init_models(AnyProduct, Catalog, CostumeCatalog, CarCatalog):
 
 
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestLazyEvaluatedSelectExpressionsForAggregates(object):
+class TestLazyEvaluatedSelectExpressionsForAggregates:
 
     def test_columns_inherited_from_parent(
         self,
@@ -111,12 +111,12 @@ class TestLazyEvaluatedSelectExpressionsForAggregates(object):
 
     def test_assigns_aggregates_on_insert(self, session, AnyProduct, Catalog):
         catalog = Catalog(
-            name=u'Some catalog'
+            name='Some catalog'
         )
         session.add(catalog)
         session.commit()
         product = AnyProduct(
-            name=u'Some product',
+            name='Some product',
             price=Decimal('1000'),
             catalog=catalog
         )
@@ -127,12 +127,12 @@ class TestLazyEvaluatedSelectExpressionsForAggregates(object):
 
     def test_assigns_aggregates_on_update(self, session, Catalog, AnyProduct):
         catalog = Catalog(
-            name=u'Some catalog'
+            name='Some catalog'
         )
         session.add(catalog)
         session.commit()
         product = AnyProduct(
-            name=u'Some product',
+            name='Some product',
             price=Decimal('1000'),
             catalog=catalog
         )
