@@ -1,5 +1,6 @@
 import pytest
 import sqlalchemy as sa
+import sqlalchemy.orm
 
 from sqlalchemy_utils import aggregated
 
@@ -67,22 +68,25 @@ def init_models(Category, Catalog, Product):
 
 
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestAggregateOneToManyAndManyToMany(object):
+class TestAggregateOneToManyAndManyToMany:
 
     def test_insert(self, session, Category, Catalog, Product):
         category = Category()
+        session.add(category)
         products = [
             Product(categories=[category]),
             Product(categories=[category])
         ]
+        [session.add(product) for product in products]
         catalog = Catalog(products=products)
         session.add(catalog)
         products2 = [
             Product(categories=[category]),
             Product(categories=[category])
         ]
+        [session.add(product) for product in products2]
         catalog2 = Catalog(products=products2)
-        session.add(catalog)
+        session.add(catalog2)
         session.commit()
         assert catalog.category_count == 1
         assert catalog2.category_count == 1
