@@ -42,13 +42,13 @@ def init_models(Thread, Comment):
 
 
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestAggregateValueGenerationWithCascadeDelete(object):
+class TestAggregateValueGenerationWithCascadeDelete:
 
     def test_something(self, session, Thread, Comment):
         thread = Thread()
-        thread.name = u'some article name'
+        thread.name = 'some article name'
         session.add(thread)
-        comment = Comment(content=u'Some content', thread=thread)
+        comment = Comment(content='Some content', thread=thread)
         session.add(comment)
         session.commit()
         session.expire_all()
