@@ -2,6 +2,7 @@ import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import create_database, database_exists, drop_database
+from sqlalchemy_utils.compat import get_sqlalchemy_version
 
 pymysql = None
 try:
@@ -9,8 +10,10 @@ try:
 except ImportError:
     pass
 
+sqlalchemy_version = get_sqlalchemy_version()
 
-class DatabaseTest(object):
+
+class DatabaseTest:
     def test_create_and_drop(self, dsn):
         assert not database_exists(dsn)
         create_database(dsn)
@@ -20,14 +23,14 @@ class DatabaseTest(object):
 
 
 @pytest.mark.usefixtures('sqlite_memory_dsn')
-class TestDatabaseSQLiteMemory(object):
+class TestDatabaseSQLiteMemory:
 
     def test_exists_memory(self, dsn):
         assert database_exists(dsn)
 
 
 @pytest.mark.usefixtures('sqlite_none_database_dsn')
-class TestDatabaseSQLiteMemoryNoDatabaseString(object):
+class TestDatabaseSQLiteMemoryNoDatabaseString:
     def test_exists_memory_none_database(self, sqlite_none_database_dsn):
         assert database_exists(sqlite_none_database_dsn)
 
@@ -66,7 +69,7 @@ class TestDatabasePostgres(DatabaseTest):
         return 'db_test_sqlalchemy_util'
 
     def test_template(self, postgresql_db_user, postgresql_db_password):
-        dsn = 'postgresql://{0}:{1}@localhost/db_test_sqlalchemy_util'.format(
+        dsn = 'postgresql://{}:{}@localhost/db_test_sqlalchemy_util'.format(
             postgresql_db_user,
             postgresql_db_password
         )
@@ -80,7 +83,7 @@ class TestDatabasePostgresPg8000(DatabaseTest):
 
     @pytest.fixture
     def dsn(self, postgresql_db_user, postgresql_db_password):
-        return 'postgresql+pg8000://{0}:{1}@localhost/{2}'.format(
+        return 'postgresql+pg8000://{}:{}@localhost/{}'.format(
             postgresql_db_user,
             postgresql_db_password,
             'db_to_test_create_and_drop_via_pg8000_driver'
@@ -91,13 +94,25 @@ class TestDatabasePostgresPsycoPG2CFFI(DatabaseTest):
 
     @pytest.fixture
     def dsn(self, postgresql_db_user, postgresql_db_password):
-        return 'postgresql+psycopg2cffi://{0}:{1}@localhost/{2}'.format(
+        return 'postgresql+psycopg2cffi://{}:{}@localhost/{}'.format(
             postgresql_db_user,
             postgresql_db_password,
             'db_to_test_create_and_drop_via_psycopg2cffi_driver'
         )
 
 
+@pytest.mark.skipif('sqlalchemy_version < (2, 0, 0)')
+class TestDatabasePostgresPsycoPG3(DatabaseTest):
+
+    @pytest.fixture
+    def dsn(self, postgresql_db_user, postgresql_db_password):
+        return 'postgresql+psycopg://{}:{}@localhost/{}'.format(
+            postgresql_db_user,
+            postgresql_db_password,
+            'db_to_test_create_and_drop_via_psycopg3_driver'
+        )
+
+
 @pytest.mark.usefixtures('postgresql_dsn')
 class TestDatabasePostgresWithQuotedName(DatabaseTest):
 
@@ -106,7 +121,7 @@ class TestDatabasePostgresWithQuotedName(DatabaseTest):
         return 'db_test_sqlalchemy-util'
 
     def test_template(self, postgresql_db_user, postgresql_db_password):
-        dsn = 'postgresql://{0}:{1}@localhost/db_test_sqlalchemy-util'.format(
+        dsn = 'postgresql://{}:{}@localhost/db_test_sqlalchemy-util'.format(
             postgresql_db_user,
             postgresql_db_password
         )
@@ -116,18 +131,18 @@ class TestDatabasePostgresWithQuotedName(DatabaseTest):
                 'TEMPLATE "my-template"') in str(excinfo.value)
 
 
-class TestDatabasePostgresCreateDatabaseCloseConnection(object):
+class TestDatabasePostgresCreateDatabaseCloseConnection:
     def test_create_database_twice(
         self,
         postgresql_db_user,
         postgresql_db_password
     ):
         dsn_list = [
-            'postgresql://{0}:{1}@localhost/db_test_sqlalchemy-util-a'.format(
+            'postgresql://{}:{}@localhost/db_test_sqlalchemy-util-a'.format(
                 postgresql_db_user,
                 postgresql_db_password
             ),
-            'postgresql://{0}:{1}@localhost/db_test_sqlalchemy-util-b'.format(
+            'postgresql://{}:{}@localhost/db_test_sqlalchemy-util-b'.format(
                 postgresql_db_user,
                 postgresql_db_password
             ),
