@@ -18,12 +18,9 @@ def columns():
     return ['_id', '_name']
 
 
-class TestGetColumns(object):
-    def test_table(self, Building):
-        assert isinstance(
-            get_columns(Building.__table__),
-            sa.sql.base.ImmutableColumnCollection
-        )
+class TestGetColumns:
+    def test_table(self, Building, columns):
+        assert [c.name for c in get_columns(Building.__table__)] == columns
 
     def test_instrumented_attribute(self, Building):
         assert get_columns(Building.id) == [Building.__table__.c._id]
