@@ -1,8 +1,9 @@
 import pytest
 import sqlalchemy as sa
+import sqlalchemy.orm
 
 from sqlalchemy_utils import get_type
-from sqlalchemy_utils.compat import get_scalar_subquery
+from sqlalchemy_utils.compat import _select_args, get_scalar_subquery
 
 
 @pytest.fixture
@@ -28,7 +29,7 @@ def Article(Base, User):
     return Article
 
 
-class TestGetType(object):
+class TestGetType:
 
     def test_instrumented_attribute(self, Article):
         assert isinstance(get_type(Article.id), sa.Integer)
@@ -46,5 +47,5 @@ class TestGetType(object):
         assert get_type(Article.author) == User
 
     def test_scalar_select(self, Article):
-        query = get_scalar_subquery(sa.select([Article.id]))
+        query = get_scalar_subquery(sa.select(*_select_args(Article.id)))
         assert isinstance(get_type(query), sa.Integer)
