@@ -2,11 +2,11 @@ import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import json_sql
-from tests import TestCase
+from sqlalchemy_utils.compat import _select_args
 
 
-class TestJSONSQL(TestCase):
-    dns = 'postgres://postgres@localhost/sqlalchemy_utils_test'
+@pytest.mark.usefixtures('postgresql_dsn')
+class TestJSONSQL:
 
     @pytest.mark.parametrize(
         ('value', 'result'),
@@ -22,12 +22,12 @@ class TestJSONSQL(TestCase):
             ([1, 2], [1, 2]),
             ([], []),
             (
-                [sa.select([sa.text('1')]).label('alias')],
+                [sa.select(*_select_args(sa.text('1'))).label('alias')],
                 [1]
             )
         )
     )
-    def test_compiled_scalars(self, value, result):
+    def test_compiled_scalars(self, connection, value, result):
         assert result == (
-            self.connection.execute(sa.select([json_sql(value)])).fetchone()[0]
+            connection.execute(sa.select(*_select_args(json_sql(value)))).fetchone()[0]
         )
