@@ -4,7 +4,7 @@ import sqlalchemy as sa
 from sqlalchemy_utils import merge_references
 
 
-class TestMergeReferences(object):
+class TestMergeReferences:
 
     @pytest.fixture
     def User(self, Base):
@@ -34,10 +34,10 @@ class TestMergeReferences(object):
         pass
 
     def test_updates_foreign_keys(self, session, User, BlogPost):
-        john = User(name=u'John')
-        jack = User(name=u'Jack')
-        post = BlogPost(title=u'Some title', author=john)
-        post2 = BlogPost(title=u'Other title', author=jack)
+        john = User(name='John')
+        jack = User(name='Jack')
+        post = BlogPost(title='Some title', author=john)
+        post2 = BlogPost(title='Other title', author=jack)
         session.add(john)
         session.add(jack)
         session.add(post)
@@ -49,10 +49,10 @@ class TestMergeReferences(object):
         assert post2.author == jack
 
     def test_object_merging_whenever_possible(self, session, User, BlogPost):
-        john = User(name=u'John')
-        jack = User(name=u'Jack')
-        post = BlogPost(title=u'Some title', author=john)
-        post2 = BlogPost(title=u'Other title', author=jack)
+        john = User(name='John')
+        jack = User(name='Jack')
+        post = BlogPost(title='Some title', author=john)
+        post2 = BlogPost(title='Other title', author=jack)
         session.add(john)
         session.add(jack)
         session.add(post)
@@ -61,11 +61,12 @@ class TestMergeReferences(object):
         # Load the author for post
         assert post.author_id == john.id
         merge_references(john, jack)
+        session.commit()
         assert post.author_id == jack.id
         assert post2.author_id == jack.id
 
 
-class TestMergeReferencesWithManyToManyAssociations(object):
+class TestMergeReferencesWithManyToManyAssociations:
 
     @pytest.fixture
     def User(self, Base):
@@ -111,9 +112,9 @@ class TestMergeReferencesWithManyToManyAssociations(object):
         pass
 
     def test_supports_associations(self, session, User, Team):
-        john = User(name=u'John')
-        jack = User(name=u'Jack')
-        team = Team(name=u'Team')
+        john = User(name='John')
+        jack = User(name='Jack')
+        team = Team(name='Team')
         team.members.append(john)
         session.add(john)
         session.add(jack)
@@ -123,7 +124,7 @@ class TestMergeReferencesWithManyToManyAssociations(object):
         assert jack in team.members
 
 
-class TestMergeReferencesWithManyToManyAssociationObjects(object):
+class TestMergeReferencesWithManyToManyAssociationObjects:
 
     @pytest.fixture
     def Team(self, Base):
@@ -179,9 +180,9 @@ class TestMergeReferencesWithManyToManyAssociationObjects(object):
         pass
 
     def test_supports_associations(self, session, User, Team, TeamMember):
-        john = User(name=u'John')
-        jack = User(name=u'Jack')
-        team = Team(name=u'Team')
+        john = User(name='John')
+        jack = User(name='Jack')
+        team = Team(name='Team')
         team.members.append(TeamMember(user=john))
         session.add(john)
         session.add(jack)
@@ -192,3 +193,61 @@ class TestMergeReferencesWithManyToManyAssociationObjects(object):
         users = [member.user for member in team.members]
         assert john not in users
         assert jack in users
+
+
+class TestMergeReferencesWithMappedProperties:
+
+    @pytest.fixture
+    def User(self, Base):
+        class User(Base):
+            __tablename__ = 'user'
+            id_ = sa.Column("id", sa.Integer, primary_key=True)
+            name = sa.Column(sa.Unicode(255))
+
+            def __repr__(self):
+                return 'User(%r)' % self.name
+        return User
+
+    @pytest.fixture
+    def Team(self, Base):
+        team_member = sa.Table(
+            'team_member', Base.metadata,
+            sa.Column(
+                'user_id', sa.Integer,
+                sa.ForeignKey('user.id', ondelete='CASCADE'),
+                primary_key=True
+            ),
+            sa.Column(
+                'team_id', sa.Integer,
+                sa.ForeignKey('team.id', ondelete='CASCADE'),
+                primary_key=True
+            )
+        )
+
+        class Team(Base):
+            __tablename__ = 'team'
+            id = sa.Column(sa.Integer, primary_key=True)
+            name = sa.Column(sa.Unicode(255))
+
+            members = sa.orm.relationship(
+                'User',
+                secondary=team_member,
+                backref='teams'
+            )
+        return Team
+
+    @pytest.fixture
+    def init_models(self, User, Team):
+        pass
+
+    def test_supports_associations(self, session, User, Team):
+        john = User(name='John')
+        jack = User(name='Jack')
+        team = Team(name='Team')
+        team.members.append(john)
+        session.add(john)
+        session.add(jack)
+        session.commit()
+        merge_references(john, jack)
+        assert john not in team.members
+        assert jack in team.members
