@@ -1,8 +1,9 @@
 import pytest
 import sqlalchemy as sa
+import sqlalchemy.orm
 from sqlalchemy.ext.hybrid import hybrid_property
 
-from sqlalchemy_utils.compat import get_scalar_subquery
+from sqlalchemy_utils.compat import _select_args, get_scalar_subquery
 from sqlalchemy_utils.relationships import select_correlated_expression
 
 
@@ -67,14 +68,14 @@ def User(Base, group_user_tbl, friendship_tbl):
         )
 
     friendship_union = (
-        sa.select([
+        sa.select(*_select_args(
             friendship_tbl.c.friend_a_id,
-            friendship_tbl.c.friend_b_id
-        ]).union(
-            sa.select([
+            friendship_tbl.c.friend_b_id,
+        )).union(
+            sa.select(*_select_args(
                 friendship_tbl.c.friend_b_id,
-                friendship_tbl.c.friend_a_id]
-            )
+                friendship_tbl.c.friend_a_id,
+            ))
         ).alias()
     )
 
@@ -157,7 +158,7 @@ def Comment(Base, Article, User):
 
     Article.comment_count = sa.orm.column_property(
         get_scalar_subquery(
-            sa.select([sa.func.count(Comment.id)])
+            sa.select(*_select_args(sa.func.count(Comment.id)))
             .where(Comment.article_id == Article.id)
             .correlate_except(Article)
         )
@@ -248,7 +249,7 @@ def dataset(
 
 
 @pytest.mark.usefixtures('dataset', 'postgresql_dsn')
-class TestSelectCorrelatedExpression(object):
+class TestSelectCorrelatedExpression:
     @pytest.mark.parametrize(
         ('model_key', 'related_model_key', 'path', 'result'),
         (
