@@ -1,7 +1,5 @@
 import pytest
-import six
 import sqlalchemy as sa
-from sqlalchemy.util.langhelpers import symbol
 
 from sqlalchemy_utils.path import AttrPath, Path
 
@@ -48,16 +46,14 @@ def SubSection(Base, Section):
     return SubSection
 
 
-class TestAttrPath(object):
+class TestAttrPath:
 
     @pytest.fixture
     def init_models(self, Document, Section, SubSection):
         pass
 
     def test_direction(self, SubSection):
-        assert (
-            AttrPath(SubSection, 'section').direction == symbol('MANYTOONE')
-        )
+        assert AttrPath(SubSection, 'section').direction.name == 'MANYTOONE'
 
     def test_invert(self, Document, Section, SubSection):
         path = ~ AttrPath(SubSection, 'section.document')
@@ -125,7 +121,7 @@ class TestAttrPath(object):
         )
 
 
-class TestPath(object):
+class TestPath:
     def test_init(self):
         path = Path('attr.attr2')
         assert path.path == 'attr.attr2'
@@ -141,10 +137,10 @@ class TestPath(object):
     @pytest.mark.parametrize(('path', 'length'), (
         (Path('s.s2.s3'), 3),
         (Path('s.s2'), 2),
-        (Path(''), 0)
+        (Path(''), 1),
     ))
     def test_len(self, path, length):
-        return len(path) == length
+        assert len(path) == length
 
     def test_reversed(self):
         path = Path('s.s2.s3')
@@ -166,7 +162,7 @@ class TestPath(object):
         assert Path('s.s2.s3').index('s2') == 1
 
     def test_unicode(self):
-        assert six.text_type(Path('s.s2')) == u's.s2'
+        assert str(Path('s.s2')) == 's.s2'
 
     def test_getitem_with_slice(self):
         path = Path('s.s2.s3')
