@@ -1,11 +1,14 @@
 import pytest
 import sqlalchemy as sa
+import sqlalchemy.orm
 
 from sqlalchemy_utils import (
     create_materialized_view,
     create_view,
     refresh_materialized_view
 )
+from sqlalchemy_utils.compat import _select_args
+from sqlalchemy_utils.view import CreateView
 
 
 @pytest.fixture
@@ -13,7 +16,7 @@ def Article(Base, User):
     class Article(Base):
         __tablename__ = 'article'
         id = sa.Column(sa.Integer, primary_key=True)
-        name = sa.Column(sa.String)
+        name = sa.Column(sa.String(128))
         author_id = sa.Column(sa.Integer, sa.ForeignKey(User.id))
         author = sa.orm.relationship(User)
     return Article
@@ -24,7 +27,7 @@ def User(Base):
     class User(Base):
         __tablename__ = 'user'
         id = sa.Column(sa.Integer, primary_key=True)
-        name = sa.Column(sa.String)
+        name = sa.Column(sa.String(128))
     return User
 
 
@@ -34,16 +37,14 @@ def ArticleMV(Base, Article, User):
         __table__ = create_materialized_view(
             name='article-mv',
             selectable=sa.select(
-                [
+                *_select_args(
                     Article.id,
                     Article.name,
                     User.id.label('author_id'),
-                    User.name.label('author_name')
-                ],
-                from_obj=(
-                    Article.__table__
-                    .join(User, Article.author_id == User.id)
+                    User.name.label('author_name'),
                 )
+            ).select_from(
+                Article.__table__.join(User, Article.author_id == User.id)
             ),
             aliases={'name': 'article_name'},
             metadata=Base.metadata,
@@ -58,16 +59,14 @@ def ArticleView(Base, Article, User):
         __table__ = create_view(
             name='article-view',
             selectable=sa.select(
-                [
+                *_select_args(
                     Article.id,
                     Article.name,
                     User.id.label('author_id'),
-                    User.name.label('author_name')
-                ],
-                from_obj=(
-                    Article.__table__
-                    .join(User, Article.author_id == User.id)
+                    User.name.label('author_name'),
                 )
+            ).select_from(
+                Article.__table__.join(User, Article.author_id == User.id)
             ),
             metadata=Base.metadata
         )
@@ -123,16 +122,18 @@ class TrivialViewTestCases:
         engine,
         metadata,
         column,
-        cascade_on_drop
+        cascade_on_drop,
+        replace=False,
     ):
-        __table__ = create_view(
+        create_view(
             name='trivial_view',
-            selectable=sa.select([column]),
+            selectable=sa.select(*_select_args(column)),
             metadata=metadata,
-            cascade_on_drop=cascade_on_drop
+            cascade_on_drop=cascade_on_drop,
+            replace=replace,
         )
-        __table__.create(engine)
-        __table__.drop(engine)
+        metadata.create_all(engine)
+        metadata.drop_all(engine)
 
 
 class SupportsCascade(TrivialViewTestCases):
@@ -149,7 +150,7 @@ class SupportsCascade(TrivialViewTestCases):
 class DoesntSupportCascade(SupportsCascade):
     @pytest.mark.xfail
     def test_life_cycle_cascade(self, *args, **kwargs):
-        super(DoesntSupportCascade, self).test_life_cycle_cascade(
+        super().test_life_cycle_cascade(
             *args,
             **kwargs
         )
@@ -166,13 +167,67 @@ class SupportsNoCascade(TrivialViewTestCases):
         self.life_cycle(engine, Base.metadata, User.id, cascade_on_drop=False)
 
 
+class SupportsReplace(TrivialViewTestCases):
+    def test_life_cycle_replace(
+        self,
+        connection,
+        engine,
+        Base,
+        User
+    ):
+        self.life_cycle(
+            engine,
+            Base.metadata,
+            User.id,
+            cascade_on_drop=False,
+            replace=True,
+        )
+
+    def test_life_cycle_replace_existing(
+        self,
+        connection,
+        engine,
+        Base,
+        User
+    ):
+        create_view(
+            name='trivial_view',
+            selectable=sa.select(*_select_args(User.id)),
+            metadata=Base.metadata,
+        )
+        Base.metadata.create_all(engine)
+        view = CreateView(
+            name='trivial_view',
+            selectable=sa.select(*_select_args(User.id)),
+            replace=True,
+        )
+        with connection.begin():
+            connection.execute(view)
+        Base.metadata.drop_all(engine)
+
+    def test_replace_materialized(
+        self,
+        connection,
+        engine,
+        Base,
+        User
+    ):
+        with pytest.raises(ValueError):
+            CreateView(
+                name='trivial_view',
+                selectable=sa.select(*_select_args(User.id)),
+                materialized=True,
+                replace=True,
+            )
+
+
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestPostgresTrivialView(SupportsCascade, SupportsNoCascade):
+class TestPostgresTrivialView(SupportsCascade, SupportsNoCascade, SupportsReplace):
     pass
 
 
 @pytest.mark.usefixtures('mysql_dsn')
-class TestMySqlTrivialView(SupportsCascade, SupportsNoCascade):
+class TestMySqlTrivialView(SupportsCascade, SupportsNoCascade, SupportsReplace):
     pass
 
 
