@@ -4,6 +4,7 @@ import pytest
 import sqlalchemy as sa
 from dateutil import tz
 
+from sqlalchemy_utils.compat import _select_args
 from sqlalchemy_utils.types import arrow
 
 
@@ -24,7 +25,7 @@ def init_models(Article):
 
 
 @pytest.mark.skipif('arrow.arrow is None')
-class TestArrowDateTimeType(object):
+class TestArrowDateTimeType:
     def test_parameter_processing(self, session, Article):
         article = Article(
             created_at=arrow.arrow.get(datetime(2000, 11, 1))
@@ -60,9 +61,9 @@ class TestArrowDateTimeType(object):
         assert article.created_at == time
 
     def test_literal_param(self, session, Article):
-        clause = Article.created_at > '2015-01-01'
+        clause = Article.created_at > datetime(2015, 1, 1)
         compiled = str(clause.compile(compile_kwargs={"literal_binds": True}))
-        assert compiled == "article.created_at > '2015-01-01'"
+        assert compiled == "article.created_at > '2015-01-01 00:00:00'"
 
     @pytest.mark.usefixtures('postgresql_dsn')
     def test_timezone(self, session, Article):
@@ -79,6 +80,6 @@ class TestArrowDateTimeType(object):
         assert item.published_at.to(timezone) == dt
 
     def test_compilation(self, Article, session):
-        query = sa.select([Article.created_at])
+        query = sa.select(*_select_args(Article.created_at))
         # the type should be cacheable and not throw exception
         session.execute(query)
