@@ -3,10 +3,11 @@ import sqlalchemy as sa
 from flexmock import flexmock
 
 from sqlalchemy_utils import Choice, ChoiceType, ImproperlyConfigured
+from sqlalchemy_utils.compat import _select_args
 from sqlalchemy_utils.types.choice import Enum
 
 
-class TestChoice(object):
+class TestChoice:
     def test_equality_operator(self):
         assert Choice(1, 1) == 1
         assert 1 == Choice(1, 1)
@@ -20,7 +21,7 @@ class TestChoice(object):
         assert hash(Choice(1, 1)) == hash(1)
 
 
-class TestChoiceType(object):
+class TestChoiceType:
     @pytest.fixture
     def User(self, Base):
         class User(Base):
@@ -48,31 +49,31 @@ class TestChoiceType(object):
 
     def test_string_processing(self, session, User):
         flexmock(ChoiceType).should_receive('_coerce').and_return(
-            u'admin'
+            'admin'
         )
         user = User(
-            type=u'admin'
+            type='admin'
         )
 
         session.add(user)
         session.commit()
 
         user = session.query(User).first()
-        assert user.type.value == u'Admin'
+        assert user.type.value == 'Admin'
 
     def test_parameter_processing(self, session, User):
         user = User(
-            type=u'admin'
+            type='admin'
         )
 
         session.add(user)
         session.commit()
 
         user = session.query(User).first()
-        assert user.type.value == u'Admin'
+        assert user.type.value == 'Admin'
 
     def test_scalar_attributes_get_coerced_to_objects(self, User):
-        user = User(type=u'admin')
+        user = User(type='admin')
 
         assert isinstance(user.type, Choice)
 
@@ -81,19 +82,19 @@ class TestChoiceType(object):
             ChoiceType([])
 
     def test_compilation(self, User, session):
-        query = sa.select([User.type])
+        query = sa.select(*_select_args(User.type))
         # the type should be cacheable and not throw exception
         session.execute(query)
 
 
-class TestChoiceTypeWithCustomUnderlyingType(object):
+class TestChoiceTypeWithCustomUnderlyingType:
     def test_init_type(self):
-        type_ = ChoiceType([(1, u'something')], impl=sa.Integer)
+        type_ = ChoiceType([(1, 'something')], impl=sa.Integer)
         assert type_.impl == sa.Integer
 
 
 @pytest.mark.skipif('Enum is None')
-class TestEnumType(object):
+class TestEnumType:
 
     @pytest.fixture
     def OrderStatus(self):
@@ -114,7 +115,7 @@ class TestEnumType(object):
             )
 
             def __repr__(self):
-                return 'Order(%r, %r)' % (self.id_, self.status)
+                return f'Order({self.id_!r}, {self.status!r})'
 
         return Order
 
