@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import pytest
 import sqlalchemy as sa
 from sqlalchemy.dialects.postgresql import ARRAY
@@ -19,7 +18,7 @@ from sqlalchemy_utils.types.range import intervals
 
 
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestCompositeTypeWithRegularTypes(object):
+class TestCompositeTypeWithRegularTypes:
 
     @pytest.fixture
     def Account(self, Base):
@@ -56,14 +55,14 @@ class TestCompositeTypeWithRegularTypes(object):
 
     def test_non_ascii_chars(self, session, Account):
         account = Account(
-            balance=(u'ääöö', 15)
+            balance=('ääöö', 15)
         )
 
         session.add(account)
         session.commit()
 
         account = session.query(Account).first()
-        assert account.balance.currency == u'ääöö'
+        assert account.balance.currency == 'ääöö'
         assert account.balance.amount == 15
 
     def test_dict_input(self, session, Account):
@@ -102,7 +101,7 @@ class TestCompositeTypeWithRegularTypes(object):
 
 @pytest.mark.skipif('i18n.babel is None')
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestCompositeTypeWithTypeDecorators(object):
+class TestCompositeTypeWithTypeDecorators:
 
     @pytest.fixture
     def Account(self, Base):
@@ -164,7 +163,7 @@ class TestCompositeTypeWithTypeDecorators(object):
 
 @pytest.mark.skipif('i18n.babel is None')
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestCompositeTypeInsideArray(object):
+class TestCompositeTypeInsideArray:
 
     @pytest.fixture
     def type_(self):
@@ -228,7 +227,7 @@ class TestCompositeTypeInsideArray(object):
 
 @pytest.mark.skipif('intervals is None')
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestCompositeTypeWithRangeTypeInsideArray(object):
+class TestCompositeTypeWithRangeTypeInsideArray:
 
     @pytest.fixture
     def type_(self):
@@ -347,7 +346,7 @@ class TestCompositeTypeWithRangeTypeInsideArray(object):
 
 
 @pytest.mark.usefixtures('postgresql_dsn')
-class TestCompositeTypeWhenTypeAlreadyExistsInDatabase(object):
+class TestCompositeTypeWhenTypeAlreadyExistsInDatabase:
 
     @pytest.fixture
     def Account(self, Base):
@@ -375,17 +374,86 @@ class TestCompositeTypeWhenTypeAlreadyExistsInDatabase(object):
         Session = sessionmaker(bind=connection)
         session = Session()
         session.execute(
-            "CREATE TYPE money_type AS (currency VARCHAR, amount INTEGER)"
+            sa.text("CREATE TYPE money_type AS (currency VARCHAR, amount INTEGER)")
         )
         session.execute(
-            """CREATE TABLE account (
+            sa.text("""CREATE TABLE account (
                 id SERIAL, balance MONEY_TYPE, PRIMARY KEY(id)
-            )"""
+            )""")
         )
 
         def teardown():
-            session.execute('DROP TABLE account')
-            session.execute('DROP TYPE money_type')
+            session.execute(sa.text('DROP TABLE account'))
+            session.execute(sa.text('DROP TYPE money_type'))
+            session.commit()
+            close_all_sessions()
+            connection.close()
+            remove_composite_listeners()
+            engine.dispose()
+
+        register_composites(connection)
+        request.addfinalizer(teardown)
+
+        return session
+
+    def test_parameter_processing(self, session, Account):
+        account = Account(
+            balance=('USD', 15),
+        )
+
+        session.add(account)
+        session.commit()
+
+        account = session.query(Account).first()
+        assert account.balance.currency == 'USD'
+        assert account.balance.amount == 15
+
+
+@pytest.mark.usefixtures('postgresql_dsn')
+class TestCompositeTypeWithMixedCase:
+
+    @pytest.fixture
+    def Account(self, Base):
+        pg_composite.registered_composites = {}
+
+        type_ = CompositeType(
+            'MoneyType',
+            [
+                sa.Column('currency', sa.String),
+                sa.Column('amount', sa.Integer)
+            ]
+        )
+
+        class Account(Base):
+            __tablename__ = 'account'
+            id = sa.Column(sa.Integer, primary_key=True)
+            balance = sa.Column(type_)
+
+        return Account
+
+    @pytest.fixture
+    def session(self, request, engine, connection, Base, Account):
+        sa.orm.configure_mappers()
+
+        Session = sessionmaker(bind=connection)
+        try:
+            # Enable sqlalchemy 2.0 behavior
+            session = Session(future=True)
+        except TypeError:
+            # sqlalchemy 1.3
+            session = Session()
+        session.execute(
+            sa.text('CREATE TYPE "MoneyType" AS (currency VARCHAR, amount INTEGER)')
+        )
+        session.execute(sa.text(
+            """CREATE TABLE account (
+                id SERIAL, balance "MoneyType", PRIMARY KEY(id)
+            )"""
+        ))
+
+        def teardown():
+            session.execute(sa.text('DROP TABLE account'))
+            session.execute(sa.text('DROP TYPE "MoneyType"'))
             session.commit()
             close_all_sessions()
             connection.close()
