@@ -2,6 +2,7 @@ import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import Country, CountryType, i18n  # noqa
+from sqlalchemy_utils.compat import _select_args
 
 
 @pytest.fixture
@@ -22,18 +23,18 @@ def init_models(User):
 
 
 @pytest.mark.skipif('i18n.babel is None')
-class TestCountryType(object):
+class TestCountryType:
 
     def test_parameter_processing(self, session, User):
         user = User(
-            country=Country(u'FI')
+            country=Country('FI')
         )
 
         session.add(user)
         session.commit()
 
         user = session.query(User).first()
-        assert user.country.name == u'Finland'
+        assert user.country.name == 'Finland'
 
     def test_scalar_attributes_get_coerced_to_objects(self, User):
         user = User(country='FI')
@@ -45,6 +46,6 @@ class TestCountryType(object):
         assert compiled == '"user".country = \'FI\''
 
     def test_compilation(self, User, session):
-        query = sa.select([User.country])
+        query = sa.select(*_select_args(User.country))
         # the type should be cacheable and not throw exception
         session.execute(query)
