@@ -2,6 +2,7 @@ import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import Currency, CurrencyType, i18n
+from sqlalchemy_utils.compat import _select_args
 
 
 @pytest.fixture
@@ -28,7 +29,7 @@ def init_models(User):
 
 
 @pytest.mark.skipif('i18n.babel is None')
-class TestCurrencyType(object):
+class TestCurrencyType:
     def test_parameter_processing(self, session, User, set_get_locale):
         user = User(
             currency=Currency('USD')
@@ -38,7 +39,7 @@ class TestCurrencyType(object):
         session.commit()
 
         user = session.query(User).first()
-        assert user.currency.name == u'US Dollar'
+        assert user.currency.name == 'US Dollar'
 
     def test_scalar_attributes_get_coerced_to_objects(
         self,
@@ -54,6 +55,6 @@ class TestCurrencyType(object):
         assert compiled == '"user".currency = \'USD\''
 
     def test_compilation(self, User, session):
-        query = sa.select([User.currency])
+        query = sa.select(*_select_args(User.currency))
         # the type should be cacheable and not throw exception
         session.execute(query)
