@@ -115,17 +115,17 @@ def test_key():
 
 @pytest.fixture
 def user_name():
-    return u'someone'
+    return 'someone'
 
 
 @pytest.fixture
 def user_phone():
-    return u'(555) 555-5555'
+    return '(555) 555-5555'
 
 
 @pytest.fixture
 def user_color():
-    return u'#fff'
+    return '#fff'
 
 
 @pytest.fixture
@@ -205,7 +205,11 @@ def user(
     session.add(user)
     session.commit()
 
-    return session.query(User).get(user.id)
+    try:
+        return session.get(User, user.id)
+    except AttributeError:
+        # sqlalchemy 1.3
+        return session.query(User).get(user.id)
 
 
 @pytest.fixture
@@ -241,7 +245,7 @@ def date_simple():
 
 
 @pytest.mark.skipif('cryptography is None')
-class EncryptedTypeTestCase(object):
+class EncryptedTypeTestCase:
 
     @pytest.fixture
     def Team(self, Base, encryption_engine, padding_mechanism):
@@ -299,14 +303,14 @@ class EncryptedTypeTestCase(object):
     def test_lookup_key(self, session, Team):
         # Add teams
         self._team_key = 'one'
-        team = Team(key=self._team_key, name=u'One')
+        team = Team(key=self._team_key, name='One')
         session.add(team)
         session.commit()
         team_1_id = team.id
 
         self._team_key = 'two'
         team = Team(key=self._team_key)
-        team.name = u'Two'
+        team.name = 'Two'
         session.add(team)
         session.commit()
         team_2_id = team.id
@@ -316,9 +320,13 @@ class EncryptedTypeTestCase(object):
             id=team_1_id
         ).one()[0]
 
-        team = session.query(Team).get(team_1_id)
+        try:
+            team = session.get(Team, team_1_id)
+        except AttributeError:
+            # sqlalchemy 1.3
+            team = session.query(Team).get(team_1_id)
 
-        assert team.name == u'One'
+        assert team.name == 'One'
 
         session.expunge_all()
 
@@ -326,9 +334,13 @@ class EncryptedTypeTestCase(object):
             id=team_2_id
         ).one()[0]
 
-        team = session.query(Team).get(team_2_id)
+        try:
+            team = session.get(Team, team_2_id)
+        except AttributeError:
+            # sqlalchemy 1.3
+            team = session.query(Team).get(team_2_id)
 
-        assert team.name == u'Two'
+        assert team.name == 'Two'
 
         session.expunge_all()
 
@@ -375,13 +387,13 @@ class TestAesEncryptedTypeTestcaseWithNaivePadding(AesEncryptedTypeTestCase):
 
     def test_decrypt_raises_value_error_with_invalid_key(self, session, Team):
         self._team_key = 'one'
-        team = Team(key=self._team_key, name=u'One')
+        team = Team(key=self._team_key, name='One')
         session.add(team)
         session.commit()
 
         self._team_key = 'notone'
         with pytest.raises(ValueError):
-            assert team.name == u'One'
+            assert team.name == 'One'
 
 
 class TestFernetEncryptedTypeTestCase(EncryptedTypeTestCase):
@@ -459,7 +471,7 @@ class TestDatetimeHandler:
 
 
 @pytest.mark.skipif('cryptography is None')
-class TestAesGcmEngine(object):
+class TestAesGcmEngine:
     KEY = b'0123456789ABCDEF'
 
     def setup_method(self):
