@@ -2,7 +2,7 @@ import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import IntRangeType
-from sqlalchemy_utils.compat import get_scalar_subquery
+from sqlalchemy_utils.compat import _select_args, get_scalar_subquery
 
 intervals = None
 inf = -1
@@ -44,7 +44,7 @@ def create_building(session, Building):
 
 
 @pytest.mark.skipif('intervals is None')
-class NumberRangeTestCase(object):
+class NumberRangeTestCase:
 
     def test_nullify_range(self, create_building):
         building = create_building(None)
@@ -100,6 +100,12 @@ class NumberRangeTestCase(object):
         assert building.persons_at_night.lower == 15
         assert building.persons_at_night.upper == 15
 
+    def test_compilation(self, session, Building):
+        query = sa.select(*_select_args(Building.persons_at_night))
+
+        # the type should be cacheable and not throw exception
+        session.execute(query)
+
 
 @pytest.mark.usefixtures('postgresql_dsn')
 class TestIntRangeTypeOnPostgres(NumberRangeTestCase):
