@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
 import pytest
 import sqlalchemy as sa
 
 from sqlalchemy_utils import i18n
+from sqlalchemy_utils.compat import _select_args
 from sqlalchemy_utils.primitives import WeekDays
 from sqlalchemy_utils.types import WeekDaysType
 
@@ -31,7 +31,7 @@ def set_get_locale():
 
 @pytest.mark.usefixtures('set_get_locale')
 @pytest.mark.skipif('i18n.babel is None')
-class WeekDaysTypeTestCase(object):
+class WeekDaysTypeTestCase:
     def test_color_parameter_processing(self, session, Schedule):
         schedule = Schedule(
             working_days=b'0001111'
@@ -48,7 +48,7 @@ class WeekDaysTypeTestCase(object):
         assert isinstance(schedule.working_days, WeekDays)
 
     def test_compilation(self, Schedule, session):
-        query = sa.select([Schedule.working_days])
+        query = sa.select(*_select_args(Schedule.working_days))
         # the type should be cacheable and not throw exception
         session.execute(query)
 
